@@ -1,11 +1,14 @@
 
-import os
-
 from . import analysis
-from .analysis import *
-
 from . import core
+from . import io
+from . import statistics
+
+from .analysis import *
 from .core import *
+from .io import *
+from .statistics import *
+
 
 # from . import simulation
 # from .simulation import *
@@ -16,32 +19,35 @@ from .core import *
 # from . import geometry
 # from .geometry import *
 
+
+
+
 # from . import viz
 # from .viz import *
 
-from . import statistics
-from .statistics import *
 
-from .io import *
+
 from .misc import *
 from .version import __version__
 
-
 # Contents
-__all__ = [
-    'io',
-    'include_dir',
-    'misc',
-    # 'simulation',
-    '__version__'
-]
-
+# __all__ = [
+#     'io',
+#     'include_dir',
+#     'misc',
+#     # 'simulation',
+#     '__version__'
+# ]
+__all__ = ['__version__']
 __all__.extend(analysis.__all__)
 __all__.extend(core.__all__)
 # __all__.extend(external.__all__)
 # __all__.extend(geometry.__all__)
+__all__.extend(io.__all__)
 __all__.extend(statistics.__all__)
 # __all__.extend(viz.__all__)
 
 # Add include path
+import os
+
 include_dir = os.path.abspath(__file__ + '/../../include')
